==> qtjambi-qt3dlogic-5.15.12-sources.jar: io/qt/qt3d/logic/QLogicAspect.java <==
package io.qt.qt3d.logic;


/**
 * <p>Responsible for handling frame synchronization jobs</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dlogic-qlogicaspect.html">Qt3DLogic::QLogicAspect</a></p>
 */
public class QLogicAspect extends io.qt.qt3d.core.QAbstractAspect
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QLogicAspect.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QLogicAspect(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QLogicAspect() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dlogic-qlogicaspect.html#QLogicAspect">Qt3DLogic::QLogicAspect::QLogicAspect(QObject*)</a></p>
     */
    public QLogicAspect(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QLogicAspect instance, io.qt.core.QObject parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QLogicAspect(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QLogicAspect(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QLogicAspect instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3dlogic-5.15.14-sources.jar: io/qt/qt3d/logic/QLogicAspect.java <==
package io.qt.qt3d.logic;

import io.qt.*;


/**
 * <p>Responsible for handling frame synchronization jobs</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dlogic-qlogicaspect.html">Qt3DLogic::QLogicAspect</a></p>
 */
public class QLogicAspect extends io.qt.qt3d.core.QAbstractAspect
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QLogicAspect.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QLogicAspect() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dlogic-qlogicaspect.html#QLogicAspect">Qt3DLogic::QLogicAspect::QLogicAspect(QObject*)</a></p>
     */
    public QLogicAspect(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QLogicAspect instance, io.qt.core.QObject parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QLogicAspect(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QLogicAspect(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QLogicAspect instance, QDeclarativeConstructor constructor);
    
}
